@@ -12,7 +12,8 @@
 
 #include "aspell.h"
 
-namespace Sonnet {
+namespace Sonnet
+{
 class SpellerPlugin;
 }
 using Sonnet::SpellerPlugin;
@@ -21,7 +22,7 @@ class ASpellClient : public Sonnet::Client
 {
     Q_OBJECT
     Q_INTERFACES(Sonnet::Client)
-    Q_PLUGIN_METADATA(IID "org.kde.Sonnet.ASpellClient")
+    Q_PLUGIN_METADATA(IID "org.kde.sonnet.Client")
 
 public:
     explicit ASpellClient(QObject *parent = nullptr);
