@@ -43,11 +43,13 @@ public:
         m_textEdit->viewport()->installEventFilter(q);
     }
 
-    ~SpellCheckDecoratorPrivate()
+    ~SpellCheckDecoratorPrivate() = default;
+
+    void removeEventFilters()
     {
         if (m_plainTextEdit) {
             m_plainTextEdit->removeEventFilter(q);
-            m_plainTextEdit->removeEventFilter(q);
+            m_plainTextEdit->viewport()->removeEventFilter(q);
         }
         if (m_textEdit) {
             m_textEdit->removeEventFilter(q);
@@ -55,6 +57,12 @@ public:
         }
     }
 
+    void onParentDestroyed()
+    {
+        m_plainTextEdit = nullptr;
+        m_textEdit = nullptr;
+    }
+
     bool onContextMenuEvent(QContextMenuEvent *event);
     void execSuggestionMenu(const QPoint &pos, const QString &word, const QTextCursor &cursor);
     void createDefaultHighlighter();
@@ -223,15 +231,24 @@ SpellCheckDecorator::SpellCheckDecorator(QTextEdit *textEdit)
     : QObject(textEdit)
     , d(std::make_unique<SpellCheckDecoratorPrivate>(this, textEdit))
 {
+    connect(textEdit, &QObject::destroyed, this, [this] {
+        d->onParentDestroyed();
+    });
 }
 
 SpellCheckDecorator::SpellCheckDecorator(QPlainTextEdit *textEdit)
     : QObject(textEdit)
     , d(std::make_unique<SpellCheckDecoratorPrivate>(this, textEdit))
 {
+    connect(textEdit, &QObject::destroyed, this, [this] {
+        d->onParentDestroyed();
+    });
 }
 
-SpellCheckDecorator::~SpellCheckDecorator() = default;
+SpellCheckDecorator::~SpellCheckDecorator()
+{
+    d->removeEventFilters();
+}
 
 void SpellCheckDecorator::setHighlighter(Highlighter *highlighter)
 {
